@@ -7,5 +7,4 @@ from vaknl_content import Content
 
 @dataclass
 class Acco(Content):
-    room_code: str
-    descriptions: list = field(default_factory=list)
+    room_code: str = None
