@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from datetime import datetime
 
 
@@ -8,7 +8,10 @@ class Content:
     giataid: int
     goalid: int
     source: str  # provider of the data
-    timestamp: str  # timestamp updated
+    labels: list = field(default_factory=list)
+    descriptions: list = field(default_factory=list)
+    language: str = None
+    timestamp: str = None  # timestamp updated
 
     def __post_init__(self):
         if isinstance(self.vaknl_acco_id, str):
